<?php
add_action(
    "woocommerce_order_status_changed",
    "send_sms_on_new_order_status",
    10,
    4
);
add_action("woocommerce_new_order", "send_sms_on_a_new_order", 50, 2);
add_action(
    "woocommerce_email_order_details",
    "send_order_details_to_customer",
    50,
    1
);
add_action(
    "woocommerce_new_customer_note",
    "send_sms_order_note_to_customer",
    50,
    1
);

global $wpdb;

$defaultMessageBody =
    "Hello {customer_full_name}! Thank you for your order! Your order {order_number} from {site_title} has been {order_status}. Here are the details of your purchase." .
    "\r\n" .
    "Order Number: {order_number}" .
    "\r\n" .
    "Order Status: {order_status}" .
    "\r\n" .
    "Order Amount: {order_amount}" .
    "\r\n" .
    "Purchase Date: {purchase_date}" .
    "\r\n" .
    "Payment Method: {payment_method}";
$defaultOrderNoteMessageBody =
    "Hello {customer_full_name}! The following note has been added to your order:" .
    "\r\n" .
    '"{order_note}"' .
    "\r\n" .
    "As a reminder, here are your order details:" .
    "\r\n" .
    "Order Number: {order_number}" .
    "\r\n" .
    "Order Status: {order_status}" .
    "\r\n" .
    "Order Amount: {order_amount}" .
    "\r\n" .
    "Purchase Date: {purchase_date}" .
    "\r\n" .
    "Payment Method: {payment_method}";
$defaultOrderInvoiceDetailsMessageBody =
    "Hello {customer_full_name}! Here are the details of your order placed on {purchase_date}:" .
    "\r\n" .
    "Order Number: {order_number}" .
    "\r\n" .
    "Order Status: {order_status}" .
    "\r\n" .
    "Order Amount: {order_amount}" .
    "\r\n" .
    "Purchase Date: {purchase_date}" .
    "\r\n" .
    "Payment Method: {payment_method}";

$isNewOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_new_order_message' LIMIT 1"
);
$isCancelledOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_cancelled_order_message' LIMIT 1"
);
$isFailedOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_failed_order_message' LIMIT 1"
);
$isOrderOnHoldOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_order_on_hold_message' LIMIT 1"
);
$isProcessingOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_processing_order_message' LIMIT 1"
);
$isCompletedOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_completed_order_message' LIMIT 1"
);
$isRefundedOrderOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_refunded_order_message' LIMIT 1"
);
$isCustomerInvoiceOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_customer_invoice_order_details_message' LIMIT 1"
);
$isCustomerNoteOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_customer_note_message' LIMIT 1"
);
$isAbandonedCartOptionExists = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_abandoned_cart_message' LIMIT 1"
);
$sveveFrom = $wpdb->query(
    "SELECT * FROM wp_options WHERE option_name ='wc_settings_tab_sms_sveve_from' LIMIT 1"
);

if (!$isNewOrderOptionExists) {
    add_option("wc_settings_tab_sms_new_order_message", $defaultMessageBody);
}

if (!$isCancelledOrderOptionExists) {
    add_option(
        "wc_settings_tab_sms_cancelled_order_message",
        $defaultMessageBody
    );
}
if (!$isFailedOrderOptionExists) {
    add_option("wc_settings_tab_sms_failed_order_message", $defaultMessageBody);
}
if (!$isOrderOnHoldOptionExists) {
    add_option(
        "wc_settings_tab_sms_order_on_hold_message",
        $defaultMessageBody
    );
}
if (!$isProcessingOrderOptionExists) {
    add_option(
        "wc_settings_tab_sms_processing_order_message",
        $defaultMessageBody
    );
}
if (!$isCompletedOrderOptionExists) {
    add_option(
        "wc_settings_tab_sms_completed_order_message",
        $defaultMessageBody
    );
}
if (!$isRefundedOrderOptionExists) {
    add_option(
        "wc_settings_tab_sms_refunded_order_message",
        $defaultMessageBody
    );
}
if (!$isCustomerInvoiceOptionExists) {
    add_option(
        "wc_settings_tab_sms_customer_invoice_order_details_message",
        $defaultOrderInvoiceDetailsMessageBody
    );
}
if (!$isCustomerNoteOptionExists) {
    add_option(
        "wc_settings_tab_sms_customer_note_message",
        $defaultOrderNoteMessageBody
    );
}
if (!$isAbandonedCartOptionExists) {
    add_option(
        "wc_settings_tab_sms_abandoned_cart_message",
        $defaultMessageBody
    );
}
if (!$sveveFrom) {
    add_option(
        "wc_settings_tab_sms_sveve_from",
        ''
    );
}

function send_sms_order_note_to_customer($wccs_custom_checkout_field_pro)
{
    $order = wc_get_order($wccs_custom_checkout_field_pro["order_id"]);

    $populatedMessageBody = [
        "{site_title}" => get_bloginfo("name"),
        "{order_number}" => $order->id,
        "{order_status}" => ucwords($order->status),
        "{purchase_date}" => date_format(
            date_create($order->date_created),
            "M d, Y H:i"
        ),
        "{order_amount}" => $order->total . $order->currency,
        "{customer_full_name}" =>
            $order->data["billing"]["first_name"] .
            " " .
            $order->data["billing"]["last_name"],
        "{payment_method}" => $order->payment_method_title,
        "{order_note}" => $wccs_custom_checkout_field_pro["customer_note"],
    ];

    $messageBody = strtr(
        get_option("wc_settings_tab_sms_customer_note_message"),
        $populatedMessageBody
    );
    $recipients = $order->data["billing"]["phone"];

    if (get_option(
        "wc_settings_tab_sms_enable_disable_customer_note_notification"
    ) === "yes"        ? true        : false
    ) {
        send_sms($order, $recipients, $messageBody);
    }
}

function send_order_details_to_customer($order)
{
    $populatedMessageBody = [
        "{site_title}" => get_bloginfo("name"),
        "{order_number}" => $order->id,
        "{order_status}" => ucwords($order->status),
        "{purchase_date}" => date_format(
            date_create($order->date_created),
            "M d, Y H:i"
        ),
        "{order_amount}" => $order->total . $order->currency,
        "{customer_full_name}" =>
            $order->data["billing"]["first_name"] .
            " " .
            $order->data["billing"]["last_name"],
        "{payment_method}" => $order->payment_method_title,
    ];

    $messageBody = strtr(
        get_option(
            "wc_settings_tab_sms_customer_invoice_order_details_message"
        ),
        $populatedMessageBody
    );
    $recipients = $order->data["billing"]["phone"];

    if (get_option(
        "wc_settings_tab_sms_enable_disable_customer_invoice_order_notification"
    ) === "yes"        ? true        : false
    ) {
        send_sms($order, $recipients, $messageBody);
    }
}

function send_sms_on_new_order_status(
    $order_id,
    $old_status,
    $new_satatus,
    $order
) {
    send_sms_to_customer($order_id, $order);

    if (($new_satatus === "cancelled") |($new_satatus === "failed") |($new_satatus === "on-hold")
    ) {
        send_sms_to_seller($order_id, $order);
    }
}

function send_sms_on_a_new_order($order_id, $order)
{
    if (get_option("wc_settings_tab_sms_enable_disable_new_order_notification")
    ) {
        send_sms_to_seller($order_id, $order, true);
        send_sms_to_customer($order_id, $order, true);
    }
}

function send_sms_to_seller($order_id, $order, $is_new_order = false)
{
    $populatedMessageBody = [
        "{site_title}" => get_bloginfo("name"),
        "{order_number}" => $order_id,
        "{order_status}" => ucwords($order->status),
        "{purchase_date}" => date_format(
            date_create($order->date_created),
            "M d, Y H:i"
        ),
        "{order_amount}" => $order->total . $order->currency,
        "{customer_full_name}" =>
            $order->data["billing"]["first_name"] .
            " " .
            $order->data["billing"]["last_name"],
        "{payment_method}" => $order->payment_method_title,
    ];

    // send new order sms notification to seller
    if ($order->status === "pending" 
        && $is_new_order 
        && get_option("wc_settings_tab_sms_new_order_recipients")        ? true        : false
    ) {
        $messageBody = strtr(
            "You’ve received the following order from {customer_full_name}:" .
                "\r\n" .
                "Order #: {order_number}" .
                "\r\n" .
                "Payment Method: {payment_method}" .
                "\r\n" .
                "Order Amount: {order_amount}",
            $populatedMessageBody
        );

        $recipients = get_option("wc_settings_tab_sms_new_order_recipients");
        send_sms($order, $recipients, $messageBody);
    }

    // send cancelled order sms notification to seller
    if ($order->status === "cancelled" 
        && get_option(
            "wc_settings_tab_sms_enable_disable_cancelled_order_notification"
        ) === "yes"        ? true        : false
    ) {
        $messageBody = strtr(
            "Notification to let you know — order #{order_number} 
            belonging to {customer_full_name} has been cancelled:" .
                "\r\n" .
                "Order #: {order_number}" .
                "\r\n" .
                "Payment Method: {payment_method}" .
                "\r\n" .
                "Order Amount: {order_amount}",
            $populatedMessageBody
        );

        $recipients = get_option(
            "wc_settings_tab_sms_cancelled_order_recipients"
        );
        send_sms($order, $recipients, $messageBody);
    }

    // send failed order sms notification to seller
    if ($order->status === "failed" 
        && get_option(
            "wc_settings_tab_sms_enable_disable_failed_order_notification"
        ) === "yes"        ? true        : false
    ) {
        $messageBody = strtr(
            "Payment for order #{order_number} from {customer_full_name} 
            has failed. The order was as follows:" .
                "\r\n" .
                "Order #: {order_number}" .
                "\r\n" .
                "Payment Method: {payment_method}" .
                "\r\n" .
                "Order Amount: {order_amount}",
            $populatedMessageBody
        );

        $recipients = get_option("wc_settings_tab_sms_failed_order_recipients");
        send_sms($order, $recipients, $messageBody);
    }
}

function send_sms_to_customer($order_id, $order, $is_new_order = false)
{
    $populatedMessageBody = [
        "{site_title}" => get_bloginfo("name"),
        "{order_number}" => $order_id,
        "{order_status}" => ucwords($order->status),
        "{purchase_date}" => date_format(
            date_create($order->date_created),
            "M d, Y H:i"
        ),
        "{order_amount}" => $order->total . $order->currency,
        "{customer_full_name}" =>
            $order->data["billing"]["first_name"] .
            " " .
            $order->data["billing"]["last_name"],
        "{payment_method}" => $order->payment_method_title,
    ];

    $recipients = $order->data["billing"]["phone"];

    // send new order sms notification to buyer
    if ($order->status === "pending" && $is_new_order) {
        $messageBody = strtr(
            get_option("wc_settings_tab_sms_new_order_message"),
            $populatedMessageBody
        );
        if (get_option(
            "wc_settings_tab_sms_enable_disable_new_order_notification"
        ) === "yes"            ? true            : false
        ) {
            send_sms($order, $recipients, $messageBody);
        }
    }

    // send on-hold order sms notification to buyer
    if ($order->status === "on-hold") {
        $messageBody = strtr(
            get_option("wc_settings_tab_sms_order_on_hold_message"),
            $populatedMessageBody
        );
        if (get_option(
            "wc_settings_tab_sms_enable_disable_order_on_hold_notification"
        ) === "yes"            ? true            : false
        ) {
            send_sms($order, $recipients, $messageBody);
        }
    }

    // send processing order sms notification to buyer
    if ($order->status === "processing") {
        $messageBody = strtr(
            get_option("wc_settings_tab_sms_processing_order_message"),
            $populatedMessageBody
        );
        if (get_option(
            "wc_settings_tab_sms_enable_disable_processing_order_notification"
        ) === "yes"            ? true            : false
        ) {
            send_sms($order, $recipients, $messageBody);
        }
    }

    // send completed order sms notification to buyer
    if ($order->status === "completed") {
        $messageBody = strtr(
            get_option("wc_settings_tab_sms_completed_order_message"),
            $populatedMessageBody
        );
        if (get_option(
            "wc_settings_tab_sms_enable_disable_completed_order_notification"
        ) === "yes"            ? true            : false
        ) {
            send_sms($order, $recipients, $messageBody);
        }
    }

    // send refunded order sms notification to buyer
    if ($order->status === "refunded") {
        $messageBody = strtr(
            get_option("wc_settings_tab_sms_refunded_order_message"),
            $populatedMessageBody
        );
        if (get_option(
            "wc_settings_tab_sms_enable_disable_refunded_order_notification"
        ) === "yes"            ? true            : false
        ) {
            send_sms($order, $recipients, $messageBody);
        }
    }
}

function send_sms($order, $recipients, $messageBody)
{
    if (get_option("wc_settings_tab_sveve_api_credentials_username")) {
        $doSendSMS = httpPost(
            "https://sveve.no/SMS/SendMessage", [
            "user" => get_option(
                "wc_settings_tab_sveve_api_credentials_username"
            ),
            "passwd" => get_option(
                "wc_settings_tab_sveve_api_credentials_password"
            ),
            "to" => $recipients,
            "msg" => $messageBody,
            "from" => get_option('wc_settings_tab_sms_sveve_from'),
            "f" => "json",
            ]
        );

        if (json_decode($doSendSMS)->response->msgOkCount) {
            $order->add_order_note(
                "SMS NOTIFICATION SENT!" . "\r\n" . $messageBody
            );
        } else {
            $order->add_order_note(
                "SMS NOTIFICATION NOT SENT!" . "\r\n" . $messageBody
            );
        }
    } else {
        $order->add_order_note(
            "SMS NOTIFICATION NOT SENT!" .
                "\r\n" .
                "Please put sveve credentials for sms notification in woocommerce settings!"
        );
    }
}

function httpPost($url, $data)
{
    $curl = curl_init($url);
    curl_setopt($curl, CURLOPT_POST, true);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($curl);
    curl_close($curl);
    return $response;
}
