<?php
/**
 * Plugin Name: SVEVE SMS-VARSLING FOR WOOCOMMERCE
 * Description: En ad on til Woo commerce som gir deg mulighet til å bruke Sveve sine sms tjenester til å sende ordre-bekreftelser på sms
 * Version: 1.0.0
 * Author: SVEVE AS
 * Author URI: https://sveve.no/
 * License: GPL2
 */

/**
 * WooCommerce Settings Page/Tab
 *
 * @package WooCommerce\Admin
 * @version 2.1.0
 */

if (!defined("ABSPATH")) {
    exit();
}

require_once __DIR__ . "/functions.php";

class SveveSmsVarslingForWooCommerce
{
    public function __construct()
    {
        add_filter(
            "woocommerce_settings_tabs_array",
            __CLASS__ . "::add_settings_tab",
            50
        );

        add_action(
            "woocommerce_settings_tabs_sms",
            __CLASS__ . "::settings_tab"
        );

        add_action(
            "woocommerce_update_options_settings_tab_sms",
            __CLASS__ . "::update_settings"
        );

        add_action("woocommerce_settings_save_sms", __CLASS__ . "::save");
    }

    public static function add_settings_tab($settings_tabs)
    {
        $settings_tabs["sms"] = "Sveve SMS";
        return $settings_tabs;
    }

    public static function settings_tab()
    {
        woocommerce_admin_fields(self::get_settings());
    }

    public static function update_settings()
    {
        woocommerce_update_options(self::get_settings());
    }

    public function get_settings()
    {
        global $current_section;

        $settings = [];

        if ($current_section === "wc_sms_new_order") {
            $settings = [
                [
                    "name" => "New Order",
                    "type" => "title",
                    "desc" => "",
                    "id" => "wc_settings_tab_sms_new_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_new_order_notification",
                ],
                [
                    "name" => "Recipient(s) #",
                    "type" => "text",
                    "desc" => "Please put comma for multiple recipients",
                    "id" => "wc_settings_tab_sms_new_order_recipients",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_new_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_new_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_cancelled_order") {
            $settings = [
                [
                    "name" => "Cancelled Order",
                    "type" => "title",
                    "desc" => "",
                    "id" => "wc_settings_tab_sms_cancelled_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_cancelled_order_notification",
                ],
                [
                    "name" => "Recipient(s) #",
                    "type" => "text",
                    "desc" => "Please put comma for multiple recipients",
                    "id" => "wc_settings_tab_sms_cancelled_order_recipients",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_cancelled_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_cancelled_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_failed_order") {
            $settings = [
                [
                    "name" => "Failed Order",
                    "type" => "title",
                    "desc" => "",
                    "id" => "wc_settings_tab_sms_failed_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_failed_order_notification",
                ],
                [
                    "name" => "Recipient(s) #",
                    "type" => "text",
                    "desc" => "Please put comma for multiple recipients",
                    "id" => "wc_settings_tab_sms_failed_order_recipients",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_failed_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_failed_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_order_on_hold") {
            $settings = [
                [
                    "name" => "	Order On-Hold",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" => "wc_settings_tab_sms_order_on_hold_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_order_on_hold_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_order_on_hold_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_order_on_hold_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_processing_order") {
            $settings = [
                [
                    "name" => "Processing Order",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" =>
                        "wc_settings_tab_sms_processing_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_processing_order_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_processing_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_processing_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_completed_order") {
            $settings = [
                [
                    "name" => "Completed Order ",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" => "wc_settings_tab_sms_completed_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_completed_order_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_completed_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_completed_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_refunded_order") {
            $settings = [
                [
                    "name" => "Refunded Order ",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" => "wc_settings_tab_sms_refunded_order_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_refunded_order_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_refunded_order_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_refunded_order_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_customer_invoice_order") {
            $settings = [
                [
                    "name" => "Customer Invoice / Order Details",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" =>
                        "wc_settings_tab_sms_customer_invoice_order_details_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_customer_invoice_order_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" =>
                        "wc_settings_tab_sms_customer_invoice_order_details_message",
                ],
                [
                    "type" => "sectionend",
                    "id" =>
                        "wc_settings_tab_sms_customer_invoice_order_details_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_customer_note") {
            $settings = [
                [
                    "name" => "Customer Note",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" => "wc_settings_tab_sms_customer_note_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_customer_note_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}, {order_note}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_customer_note_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_customer_note_section_end",
                ],
            ];
        } elseif ($current_section === "wc_sms_abandoned_cart") {
            $settings = [
                [
                    "name" => "Abandoned Cart",
                    "type" => "title",
                    "desc" => "Recipient: Customer",
                    "id" => "wc_settings_tab_sms_abandoned_cart_section_title",
                ],
                [
                    "title" => "Enable Notification",
                    "type" => "checkbox",
                    "id" =>
                        "wc_settings_tab_sms_enable_disable_abandoned_cart_notification",
                ],
                [
                    "name" => "Message Body",
                    "type" => "textarea",
                    "desc" =>
                        "These are the variables you can use: {site_title}, {order_number}, {order_status}, {order_amount}, {purchase_date}, {customer_full_name}, {payment_method}",
                    "css" => "height: 165px;",
                    "id" => "wc_settings_tab_sms_abandoned_cart_message",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sms_abandoned_cart_section_end",
                ],
            ];
        }

        if (!$current_section) {
            $settings = [
                [
                    "name" => "SVEVE API CREDENTIAL",
                    "type" => "title",
                    "desc" => "Please go to <a href='https://sveve.no/'>https://sveve.no</a> to get your API credentials.",
                    "id" =>
                        "wc_settings_tab_sveve_api_credentials_section_title",
                ],
                [
                    "name" => "From",
                    "type" => "text",
                    "id" => "wc_settings_tab_sms_sveve_from",
                ],
                [
                    "name" => "Username",
                    "type" => "text",
                    "id" => "wc_settings_tab_sveve_api_credentials_username",
                ],
                [
                    "name" => "API Password",
                    "type" => "text",
                    "id" => "wc_settings_tab_sveve_api_credentials_password",
                ],
                [
                    "type" => "sectionend",
                    "id" => "wc_settings_tab_sveve_api_credentials_section_end",
                ],
            ];

            self::table();
        }

        return apply_filters("wc_settings_tab_sms_settings", $settings);
    }

    public function table()
    {
        echo "<h2>SVEVE SMS NOTIFICATIONS</h2>
        <p>Email notifications sent from WooCommerce are listed below.</p>
        <table cellpadding='12' width='100%' style='background: #ccc;'>
            <tr>
                <th style='background: #ccc; text-align: left;'>SMS</th>
                <th style='background: #ccc; text-align: left;'>Recipients</th>
                <th style='background: #ccc; text-align: left;'>Enabled/Disabled</th>
                <th style='background: #ccc; text-align: left;'>Settings</th>
            </tr>
            <tr>
                <td style='background: #fff;'>New Order</td>
                <td style='background: #fff;'>" .
            get_option("wc_settings_tab_sms_new_order_recipients") .
            "</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_new_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_new_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Cancelled Order</td>
                <td style='background: #fff;'>" .
            get_option("wc_settings_tab_sms_cancelled_order_recipients") .
            "</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_cancelled_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_cancelled_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Failed Order</td>
                <td style='background: #fff;'>" .
            get_option("wc_settings_tab_sms_failed_order_recipients") .
            "</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_failed_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_failed_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Order On-Hold</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_order_on_hold_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_order_on_hold"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Processing Order</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_processing_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_processing_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Completed Order</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_completed_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_completed_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Refund Order</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_refunded_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_refunded_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Customer Invoice / Order Details</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_customer_invoice_order_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_customer_invoice_order"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Customer Note</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_customer_note_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_customer_note"
            ) .
            ">Manage</a></td>
            </tr>
            <tr>
                <td style='background: #fff;'>Abandoned Cart</td>
                <td style='background: #fff;'>Customer</td>
                <td style='background: #fff;'>" .
            (get_option(
                "wc_settings_tab_sms_enable_disable_abandoned_cart_notification"
            ) === "yes"
                ? "Enabled"
                : "Disabled") .
            "</td>
                <td style='background: #fff;'><a style='text-decoration: none; padding: 5px 20px; border-radius: 3px; color: #2271b1; background: #f6f7f7; border: 1px solid #2271b1;' href=" .
            admin_url(
                "admin.php?page=wc-settings&tab=sms&section=wc_sms_abandoned_cart"
            ) .
            ">Manage</a></td>
            </tr>
        </table>";
    }
    public function save()
    {
        global $current_section;

        $settings = self::get_settings();

        WC_Admin_Settings::save_fields($settings);

        if ($current_section) {
            do_action("woocommerce_update_options_sms_" . $current_section);
        }
    }
}

if (class_exists("SveveSmsVarslingForWooCommerce")) {
    $sveveSmsVarslingForWooCommerce = new SveveSmsVarslingForWooCommerce();
}
